magneticalc.QtWidgets2.QGroupBox2.QGroupBox2

# ``magneticalc`.`QtWidgets2`.`QGroupBox2`.`QGroupBox2``

class documentation

`class QGroupBox2(QGroupBox, QLayouted):`

Known subclasses: `magneticalc.Display_Widget.Display_Widget`, `magneticalc.Field_Widget.Field_Widget`, `magneticalc.Metric_Widget.Metric_Widget`, `magneticalc.Parameters_Widget.Parameters_Widget`, `magneticalc.Perspective_Widget.Perspective_Widget`, `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget`, `magneticalc.Wire_Widget.Wire_Widget`

Constructor: `QGroupBox2(title, color)`

View In Hierarchy

QGroupBox2 class.

Method | `__init__` | Initializes a groupbox.
Method | `set_color` | Sets the style and label color of the groupbox.

Inherited from `QLayouted`:

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self, title: `str`, color: `str`):
overrides `magneticalc.QtWidgets2.QLayouted.QLayouted.__init__`
overridden in `magneticalc.Display_Widget.Display_Widget`, `magneticalc.Field_Widget.Field_Widget`, `magneticalc.Metric_Widget.Metric_Widget`, `magneticalc.Parameters_Widget.Parameters_Widget`, `magneticalc.Perspective_Widget.Perspective_Widget`, `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget`, `magneticalc.Wire_Widget.Wire_Widget`

Initializes a groupbox.

Parameters
title: `str` | Title
color: `str` | Undocumented

def set_color(self, color: `str`):

Sets the style and label color of the groupbox.

Parameters
color: `str` | Label color